..
  SPDX-FileCopyrightText: 2016-2019 The Atlite Authors

  SPDX-License-Identifier: CC-BY-4.0

#############
API Reference
#############

Cutout
------

.. autoclass:: atlite.Cutout
    :members:


Data
------

.. automodule:: atlite.data
    :members:


Convert
-------

.. automodule:: atlite.convert
    :members:


Resource
--------

.. automodule:: atlite.resource
    :members:

Wind
----

.. automodule:: atlite.wind
    :members:

GIS
-------

.. automodule:: atlite.gis
    :members:


Utils
-----

.. automodule:: atlite.utils
    :members: